/* -*- C++ -*- */
/* This file is part of
 * ======================================================
 * 
 *           LyX, the High Level Word Processor
 *        
 *           Copyright (C) 1995Matthias Ettrich
 *           Copyright (C) 1995-1998 The LyX Team.
 *
 * ======================================================
 A few prototypes and definitions needed for Windows NT */

/* Hacks to get LyX running under Win-NT w. Cygnus b19 (steven@cs.uu.nl) */

#ifndef NT_DEFINES_H
#define NT_DEFINES_H


#endif /* NT_DEFINES_H */
